@@ -1,24 +1,21 @@
 #!/usr/bin/python
+#  $Id: cdio.py,v 1.6 2008/05/01 16:55:03 karl Exp $
 #
-#    $Id: cdio.py,v 1.5 2006/12/10 21:50:00 rocky Exp $
+#  Copyright (C) 2006, 2008 Rocky Bernstein <rocky@gnu.org>
 #
-#    Copyright (C) 2006 Rocky Bernstein <rocky@gnu.org>
+#  This program is free software: you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation, either version 3 of the License, or
+#  (at your option) any later version.
 #
-#    This program is free software; you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 2 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-#    02110-1301 USA.
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
 #
+#  You should have received a copy of the GNU General Public License
+#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 """The CD Input and Control library (pycdio) encapsulates CD-ROM 
 reading and control. Applications wishing to be oblivious of the OS-
 and device-dependent properties of a CD-ROM can use this library."""
@@ -46,24 +43,27 @@ class TrackError(DeviceException): pass
 drivers = {
     'Unknown'  : pycdio.DRIVER_UNKNOWN,
     'AIX'      : pycdio.DRIVER_AIX,
-    'aix'      : pycdio.DRIVER_AIX,
     'BSDI'     : pycdio.DRIVER_BSDI,
-    'bsdi'     : pycdio.DRIVER_BSDI,
     'FreeBSD'  : pycdio.DRIVER_FREEBSD,
-    'freebsd'  : pycdio.DRIVER_FREEBSD,
     'GNU/Linux': pycdio.DRIVER_LINUX,
+    'linux'    : pycdio.DRIVER_LINUX,
     'Solaris'  : pycdio.DRIVER_SOLARIS,
-    'solaris'  : pycdio.DRIVER_SOLARIS,
     'OS X'     : pycdio.DRIVER_OSX,
+    'osx'      : pycdio.DRIVER_OSX,
     'WIN32'    : pycdio.DRIVER_WIN32,
     'CDRDAO'   : pycdio.DRIVER_CDRDAO,
-    'cdrdao'   : pycdio.DRIVER_CDRDAO,
     'BIN/CUE'  : pycdio.DRIVER_BINCUE,
     'NRG'      : pycdio.DRIVER_NRG,
     'Nero'     : pycdio.DRIVER_NRG,
     'device'   : pycdio.DRIVER_DEVICE
     }
 
+if pycdio.VERSION_NUM >= 82:
+    drivers['NetBSD'] = pycdio.DRIVER_NETBSD
+
+for name in drivers.keys():
+    drivers[name.lower()] = drivers[name]
+
 read_mode2blocksize = {
     pycdio.READ_MODE_AUDIO: pycdio.CD_FRAMESIZE_RAW,
     pycdio.READ_MODE_M1F1:  pycdio.M2RAW_SECTOR_SIZE,
